@@ -4,6 +4,7 @@ const { Gdk, Gio, GLib, GObject, Gtk, TelepathyGLib: Tp } = imports.gi;
 
 const { AccountsMonitor } = imports.accountsMonitor;
 const { RoomManager } = imports.roomManager;
+const { UserStatusMonitor } = imports.userTracker;
 
 const MIN_SPINNER_TIME = 1000000;   // in microsecond
 
@@ -33,9 +34,16 @@ var RoomRow = GObject.registerClass({
         this._room = room;
         this._popover = null;
 
+        const mon = UserStatusMonitor.getDefault();
+        this._userTracker = mon.getUserTrackerForAccount(this.account);
+
         this._connectingTimeoutId = 0;
 
-        this._icon.gicon = room.icon;
+        this._mutedIcon = new Gio.EmblemedIcon({ gicon: room.icon });
+        this._mutedIcon.add_emblem(new Gio.Emblem({
+            icon: new Gio.ThemedIcon({ name: 'emblem-unreadable' }),
+        }));
+
         this._icon.visible = room.icon !== null;
 
         this._eventBox.connect('button-release-event',
@@ -51,12 +59,18 @@ var RoomRow = GObject.registerClass({
             this._onChannelChanged.bind(this));
 
         let connectionStatusChangedId = 0;
+        let mutedChangedId = 0;
 
         if (this._room.type === Tp.HandleType.ROOM) {
             connectionStatusChangedId =
                 this.account.connect('notify::connection-status',
                     this._onConnectionStatusChanged.bind(this));
             this._onConnectionStatusChanged();
+        } else {
+            mutedChangedId = this._userTracker.connect(
+                `muted-changed::${room.channel_name}`,
+                this._onMutedChanged.bind(this));
+            this._onMutedChanged();
         }
 
         this.connect('destroy', () => {
@@ -64,6 +78,8 @@ var RoomRow = GObject.registerClass({
             this._channelSignals.forEach(id => {
                 room.channel.disconnect(id);
             });
+            if (mutedChangedId)
+                this._userTracker.disconnect(mutedChangedId);
             if (connectionStatusChangedId)
                 this.account.disconnect(connectionStatusChangedId);
             this._clearConnectingTimeout();
@@ -86,6 +102,10 @@ var RoomRow = GObject.registerClass({
         return !this.get_style_context().has_class('inactive');
     }
 
+    get muted() {
+        return this._userTracker.isMuted(this._room.channel_name);
+    }
+
     selected() {
         if (!this._room.channel)
             this._updatePending();
@@ -98,6 +118,9 @@ var RoomRow = GObject.registerClass({
         let pending = this._room.channel.dup_pending_messages();
         let nPending = pending.length;
 
+        if (this.muted)
+            return [nPending, 0];
+
         let highlights = pending.filter(m => {
             let [text] = m.to_text();
             return this._room.should_highlight_message(m.sender.alias, text);
@@ -130,6 +153,15 @@ var RoomRow = GObject.registerClass({
         }
     }
 
+    _onMutedChanged() {
+        if (this.muted)
+            this._icon.gicon = this._mutedIcon;
+        else
+            this._icon.gicon = this.room.icon;
+
+        this._updatePending();
+    }
+
     _updatePending() {
         let [nPending, nHighlights] = this._getNumPending();
 
@@ -154,8 +186,7 @@ var RoomRow = GObject.registerClass({
         for (let signal of ['message-received', 'pending-message-removed']) {
             this._channelSignals.push(
                 this._room.channel.connect(signal,
-                    this._updatePending.bind(this))
-            );
+                    this._updatePending.bind(this)));
         }
         this._updatePending();
     }
@@ -184,17 +215,8 @@ var RoomRow = GObject.registerClass({
     }
 
     _showPopover() {
-        if (!this._popover) {
-            let menu = new Gio.Menu();
-            let isRoom = this._room.type === Tp.HandleType.ROOM;
-            let label = isRoom ?  _('Leave chatroom') : _('End conversation');
-            menu.append(label, `app.leave-room(("${this._room.id}", ""))`);
-
-            this._popover = Gtk.Popover.new_from_model(this, menu);
-            this._popover.connect('notify::visible',
-                _onPopoverVisibleChanged);
-            this._popover.position = Gtk.PositionType.BOTTOM;
-        }
+        if (!this._popover)
+            this._popover = new RoomRowPopover(this);
         this._popover.popup();
     }
 
@@ -205,6 +227,58 @@ var RoomRow = GObject.registerClass({
     }
 });
 
+const RoomRowPopover = GObject.registerClass(
+class RoomRowPopover extends Gtk.Popover {
+    _init(row) {
+        super._init({
+            relative_to: row,
+            position: Gtk.PositionType.BOTTOM,
+        });
+
+        this.connect('notify::visible', _onPopoverVisibleChanged);
+
+        this._row = row;
+        this._menu = new Gio.Menu();
+        const isRoom = row.room.type === Tp.HandleType.ROOM;
+
+        if (!isRoom) {
+            this._muteItem = new Gio.MenuItem();
+            this._muteTarget = new GLib.Variant('(ss)', [
+                row.account.object_path,
+                row.room.channel_name,
+            ]);
+            this._menu.append_item(this._muteItem);
+        }
+
+        const label = isRoom ?  _('Leave chatroom') : _('End conversation');
+        this._menu.append(label, `app.leave-room(("${this._row.room.id}", ""))`);
+
+        this.bind_model(this._menu, null);
+    }
+
+    vfunc_map() {
+        if (this._row.room.type !== Tp.HandleType.ROOM)
+            this._updateMuteItem();
+        super.vfunc_map();
+    }
+
+    _updateMuteItem() {
+        this._menu.remove(0);
+
+        if (this._row.muted) {
+            this._muteItem.set_label(_('Unmute'));
+            this._muteItem.set_action_and_target_value(
+                'app.unmute-nick', this._muteTarget);
+        } else {
+            this._muteItem.set_label(_('Mute'));
+            this._muteItem.set_action_and_target_value(
+                'app.mute-nick', this._muteTarget);
+        }
+
+        this._menu.insert_item(0, this._muteItem);
+    }
+});
+
 var RoomListHeader = GObject.registerClass({
     CssName: 'row',
     Template: 'resource:///org/gnome/Polari/ui/room-list-header.ui',
@@ -496,13 +570,13 @@ class RoomList extends Gtk.ListBox {
             name: 'next-pending-room',
             handler: () => {
                 this._moveSelectionFull(Gtk.DirectionType.DOWN,
-                    row => row.hasPending);
+                    row => row.hasPending && !row.muted);
             },
         }, {
             name: 'previous-pending-room',
             handler: () => {
                 this._moveSelectionFull(Gtk.DirectionType.UP,
-                    row => row.hasPending);
+                    row => row.hasPending && !row.muted);
             },
         }];
         actions.forEach(a => {
