@@ -4,6 +4,7 @@ const { Gio, GLib, GObject, Polari, TelepathyGLib: Tp } = imports.gi;
 
 const { AccountsMonitor } = imports.accountsMonitor;
 const { RoomManager } = imports.roomManager;
+const { UserStatusMonitor } = imports.userTracker;
 const Utils = imports.utils;
 
 const SHELL_CLIENT_PREFIX = 'org.freedesktop.Telepathy.Client.GnomeShell';
@@ -136,6 +137,8 @@ class TelepathyClient extends Tp.BaseClient {
         this._accountsMonitor = AccountsMonitor.getDefault();
         this._accountsMonitor.prepare(this._onPrepared.bind(this));
 
+        this._userStatusMonitor = UserStatusMonitor.getDefault();
+
         this._shellHandlesPrivateChats = false;
         this._monitorShellClient();
     }
@@ -237,6 +240,17 @@ class TelepathyClient extends Tp.BaseClient {
         });
         this.register();
 
+        if (Utils.needsOnetimeAction('mute-bots')) {
+            this._accountsMonitor.visibleAccounts.forEach(a => {
+                if (a.settings.get_string('identify-username') === null)
+                    return;
+
+                const tracker =
+                    this._userStatusMonitor.getUserTrackerForAccount(a);
+                tracker.muteNick(a.settings.get_string('identify-botname'));
+            });
+        }
+
         this._accountsMonitor.connect('account-status-changed',
             this._onAccountStatusChanged.bind(this));
         this._accountsMonitor.connect('account-reachable-changed',
@@ -277,9 +291,8 @@ class TelepathyClient extends Tp.BaseClient {
         if (!account.enabled)
             return;
 
-        let statuses = Object.keys(Tp.ConnectionPresenceType).map(s =>
-            s.replace(/_/g, '-').toLowerCase()
-        );
+        let statuses = Object.keys(Tp.ConnectionPresenceType)
+            .map(s => s.replace(/_/g, '-').toLowerCase());
         let status = statuses[presence];
         let msg = account.requested_status_message;
         let accountName = account.display_name;
@@ -504,6 +517,10 @@ class TelepathyClient extends Tp.BaseClient {
 
         settings.set_string('identify-username', data.username);
         settings.set_boolean('identify-username-supported', data.usernameSupported);
+
+        // We know it's a bot, mute it by default!
+        let tracker = this._userStatusMonitor.getUserTrackerForAccount(account);
+        tracker.muteNick(data.botname);
     }
 
     _onDiscardIdentifyPasswordActivated(action, parameter) {
@@ -676,6 +693,10 @@ class TelepathyClient extends Tp.BaseClient {
         if (this._shellHandlesPrivateChats && room.type === Tp.HandleType.CONTACT)
             return;
 
+        const tracker = this._userStatusMonitor.getUserTrackerForAccount(room.account);
+        if (tracker.isMuted(msg.sender.identifier))
+            return;
+
         let summary;
 
         if (room.type === Tp.HandleType.CONTACT) {
